****************************
The sherpa.instrument module
****************************

.. currentmodule:: sherpa.instrument

.. automodule:: sherpa.instrument

   .. rubric:: Classes
               
   .. autosummary::
      :toctree: api

      ConvolutionKernel
      ConvolutionModel
      Kernel
      PSFKernel
      PSFModel
      RadialProfileKernel
   
Class Inheritance Diagram
=========================

.. inheritance-diagram:: ConvolutionKernel ConvolutionModel PSFModel Kernel PSFKernel RadialProfileKernel
